@@ -37,9 +37,8 @@ async def get_hfox(id: int = choose().hentaifox):
             if r.status_code == 200:
                 img_url = img_url
             else:
-                img_url = img_url.replace('.jpg', '.png') or img_url.replace('.png', '.jpg')
+                img_url = re.sub(r'(?<=\d{3})\d{3}', r.status_code, img_url)
         except:
-            ext = '.jpg'
             img_url = img_url.replace('.jpg', '.png')
 
         img_name = img_url.rsplit('/', 1)[-1]
